@@ -1,21 +1,9 @@
 /*
- *  This file is part of the KDE project
- *  Copyright (C) 1998-2005 David Faure <faure@kde.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- **/
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998-2005 David Faure <faure@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef __konq_view_h__
 #define __konq_view_h__
@@ -103,6 +91,8 @@ public:
 
     ~KonqView() override;
 
+    bool isWebEngineView() const;
+
     /**
      * Displays another URL, but without changing the view mode (caller has to
      * ensure that the call makes sense)
@@ -349,6 +339,18 @@ public:
      */
     bool supportsMimeType(const QString &mimeType) const;
 
+    /**
+     * Whether the view in this part is suitable for web browsing.
+     *
+     * @return @b true if the part is suitable for browsing and @b false otherwise
+     *
+     * @warning Unfortunately, as far as I know, there's no way to detect whether a part is
+     * suitable for browsing. This function works by hardcoding the component names of such
+     * parts (currently only khtml, kwebkitpart and webenginepart). If other browsing parts
+     * will be added, the list should be changed or another way must be found.
+     **/
+    bool isWebBrowsingPart() const;
+
     // True if showing a directory
     bool showsDirectory() const;
 
